#ifndef __UNIFIED_APIS_H__
#define __UNIFIED_APIS_H__

#include <err.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <stdbool.h>
#include <stdint.h>
#include "kyee_security.h"
#include "tpm_security.h"


union TrustedBootMeasureData
{
    /*kyee 度量数据*/
    struct BootMeasureData kyee_bootMeasureData;
    /*tpm 度量数据*/
    struct TPMBootMeasureData tpm_bootMeasureData;
};


union TrustedBootMeasureLog
{
    /* kyee 历史度量数据 */
    struct BootMeasureLog kyee_bootMeasureLog;
    /* tpm 历史度量数据 */
    struct TPMBootMeasureLog tpm_bootMeasureLog;
};

#ifdef __cplusplus
extern "C" {
#endif


/**
 * @brief 获取可信根数据
 * 
 * @param data 可信根数据的json格式
 * @return 0， success, 
 *         other, failed
 */
int TRUSTED_GetTrustedRootData(char *data);
/**
 * @brief 获取当前系统启动度量策略状态
 * 
 * @return -1， 失败；0 关闭； 1 初始化；2 开启； 3 警告；
 */
int TRUSTED_GetBootMeasureStatus();
/**
 * @brief 获取系统配置启动度量策略状态
 * 
 * @return 0 关闭； 1 初始化；2 开启； 3 警告； 其他 失败 
 */
int TRUSTED_GetBootMeasureCfgStatus();
/**
 * @brief 设置启动度量策略状态
 * 
 * @param status 度量策略状态， 0 关闭； 2 开启； 3 警告
 * @return 0， 成功，-1， 失败
 */
int TRUSTED_SetBootMeasureCfgStatus(int status);
/**
 * @brief 设置重新采集度量值
 * 
 * @param status 重新采集度量值 (0,不采集; 1,重新采集)
)
 * @return 0， 成功； -1， 失败
 */
int TRUSTED_SetReCollectMeasureStandarValue(int status);
/**
 * @brief 获取重新采集度量值 
 * 
 * @return 0,不采集; 1,重新采集； -1， 失败 
 */
int TRUSTED_GetReCollectMeasureStandarValue();
/**
 * @brief 获取启动模式
 * 
 * @return  启动模式(0 同步； 1 混合；2 异步； 其他 失败)
 */
int TRUSTED_GetBootMode();
/**
 * @brief 设置启动模式
 * 
 * @param status 启动模式 ( 0 同步 1 混合 2 异步)
 * @return 0， 成功；其他失败
 */
int TRUSTED_SetBootMode(int status); 
/**
 * @brief flash启动日志存储
 * 
 * @return 0， 成功；其他失败 
 */
int TRUSTED_SaveFlashBootMeasureLog(); 

/**
 * @brief 获取当前启动报告
 * 
 * @param list 当前启动报告数据
 * @param count 数据数量
 * @return 0， 成功；其他失败
 */
int TRUSTED_GetBootMeasureData(union TrustedBootMeasureData **list, int *count);
/**
 * @brief 获取历史启动报告
 * 
 * @param list 历史启动报告数据
 * @param count 数据数量
 * @return 0， 成功；其他失败 
 */
int TRUSTED_GetHistoryBootMeasureLog(union TrustedBootMeasureLog **list, int *count);

/**
 * @brief 获取当前使用的可信模式
 * 
 * @param trustMode 可信模式（1，kyee; 2, tpm）
 * @return 0， success, 
 *         other, failed
 */
int TRUSTED_GetCurrentUseTrustMode(int* trustMode);

#ifdef __cplusplus
}
#endif

#endif //__UNIFIED_APIS_H__
